@@ -36,6 +36,10 @@ def remove_unneeded_f_strings(
         # ASTs start at line 1, but we expect our lists to start at 0
         line_no = unneeded_f_string.lineno - 1
 
+        # in case a string like rf'hello' exists
+        if content_list[line_no][loc] == 'r':
+            loc += 1
+
         # A safety check, we should never remove a character that's not 'f'
         # This can occur during the following line of python code, for example:
         #
